@@ -2,7 +2,8 @@
     function(g,maxTotalPs=NULL,minTotalPs=NULL,
         contig=TRUE,atLeastOne=TRUE,atLeastOneOfEach=FALSE,KIC=1,kIC=1,fullGrid=FALSE,
         m1=-90,p=-1,forceM1=FALSE,forceP=FALSE) {
-  # This function makes a chunk of grid graph models. It is less advanced than its counterpart mkSpurs because I still need a way
+  # This function makes a chunk of grid graph models. It is less advanced than its counterpart mkSpurs 
+  # because I still need a way
   # of going through this model space systematically with increasing numbers of parameters. Thus, it does 
   # not have state inputs and output. Note that it is implicit that R is always a thread head too
   
@@ -298,11 +299,11 @@
 #  break
 #  if (!is.null(maxnPs)) Bmats=Bmats[Bmats$nParams<=maxnPs,]
   chunk=Bmats
-  print(chunk)
+#  print(chunk)
   keqs=mkEq(g,chunk,activity=TRUE)
   Keqs=mkEq(g,chunk) # whether g$activity if TRUE or FALSE, we want activity = FALSE in this function call
-  print(chunk)
-  print(Keqs)
+#  print(chunk)
+#  print(Keqs)
   if (!fullGrid){ # if full grid not wanted, remove it
     pNulls=which(sapply(Keqs,is.null))
 # the next two lines remove grids that are really spurs
@@ -312,7 +313,7 @@
       keqs=keqs[-pNulls]
     }
   }
-  print(Keqs)
+#  print(Keqs)
   
   
   
@@ -364,7 +365,7 @@
 }
 
 
-# by placing this last function definition after the main function if becomes available to mkSpurs  
+# placing this last function definition after the main function makes it available to mkSpurs  
 
 mkm<-function(chunk,m1){
   if (m1<0) {
