@@ -143,15 +143,15 @@
 #    print(Mrnms)    
     condens<-function(x) apply(x,1,paste,collapse="")
     Crnms=lapply(Mrnms,condens)
-    print(Crnms)
+#    print(Crnms)
     lens=lapply(Crnms,length)
-    print(lens)
+#    print(lens)
     prepkPs<-function(x) apply(x,1,unique)
     countkPs<-function(x) sapply(x,length)
     unikPs=lapply(Mrnms,prepkPs)
-    print(unikPs)
+#    print(unikPs)
     nkPs=lapply(unikPs,countkPs)
-    print(nkPs)
+#    print(nkPs)
     rowList=NULL
     for (i in 1:dim(spurs)[1]){
       tmp=spurs[i,,drop=FALSE]
@@ -179,7 +179,7 @@
     } 
     rowList=rowList[order(rowList$nParams),]
     rowList$indx=1:(dim(rowList)[1])
-    print(rowList)
+#    print(rowList)
     spurs=rowList
   }
   if (!g$activity) keqs=NULL else keqs=mkEq(g,spurs,activity=TRUE)
@@ -187,6 +187,7 @@
   # now trim it down to just those with up to maxTotalPs parameters
   if (!is.null(maxTotalPs)) spurs=spurs[spurs$nParams<=maxTotalPs,] 
   if (!is.null(minTotalPs)) spurs=spurs[spurs$nParams>=minTotalPs,] 
+#  g$W[g$Z,"S",drop=F]==0  # do something with this later to kill k in S=0 complexes
   if (forceM1) spurs=spurs[spurs$m1>0,] 
   if (forceP) spurs=spurs[spurs$p>0,] 
   state$globMdlIndex=state$globMdlIndex+dim(spurs)[1]
