@@ -101,9 +101,9 @@
     strn=paste(strn,sprintf("%10sT = parmsTCC[\"%sT\"]\n",g$atomS[1],g$atomS[1]),sep="")
     for (i in 2:g$nAtomS)
       strn=paste(strn,sprintf("%10s = parmsTCC[\"%sF\"]\n",g$atomS[i],g$atomS[i]),sep="")
-    strn=paste(strn,sprintf("%10s = 1\n","R"),sep="")
+    strn=paste(strn,sprintf("%10s = 1\n",g$hubChar),sep="")
     for (i in 1:g$nZ)
-    {Stothen=paste(rep(g$atomS[2],g$W[g$Z[i],2]),collapse="*")
+    {if (g$W[g$Z[i],2]>0) Stothen=paste(rep(g$atomS[2],g$W[g$Z[i],2]),collapse="*") else Stothen="1"
       strn=paste(strn,sprintf("%10s = %s/parmsTCC[\"Kj_%s\"];\n",g$Z[i],Stothen,g$Z[i]),sep="")
     }
     uniW=unique(g$W[,1])
@@ -112,7 +112,7 @@
     pows=1:max(uniW)
 #    print(rnms)
 #    print(newW)
-    strn=paste(strn,"Rpoly=c(RT,",sep="")
+    strn=paste(strn,"Rpoly=c(",g$hubChar,"T,",sep="")
     for (j in pows) { print(j)
       str<-paste(rnms[which(newW==j)],collapse="+")
       if (str=="") str="0"
@@ -298,7 +298,7 @@
   library(odesolve); 
 #  gObj=mkgC(gObj)
   if (TCC&!free) { gObj=mkgC(gObj); testgC(gObj)} else {
-    if (activity) gObj=mkRP(gObj)
+    if ((activity)&(gObj$singleThread)) gObj=mkRP(gObj)
   }
   if (free) { library(PolynomF); gObj=mkPoly(gObj)}
 #  if (free) { library(polynom); gObj=mkPoly(gObj)}
