@@ -16,4 +16,4 @@ d2=subset(RNR,year==2006,select=c(R,t,m,year))
 dd=rbind(d1,d2) 
 names(dd)[1:2]=c("RT","tT")
 # the next line takes <13 minutes 
-tops=ems(dd,g,pRows=T,doTights=T)
+tops=ems(dd,g)
