@@ -27,33 +27,34 @@ print(host)
       )
   )
   dd=subset(RNR,(year==2002)&(fg==1)&(X>0),select=c(R,X,m,year))
-  names(dd)[1:2]=c("RT","XF")
+  free=TRUE
+  names(dd)[1:2]=c("RT",paste("X",ifelse(free,"F","T"),sep=""))
 #dd=dd[-12,]  # outlier that raises things to cause the downturn
 #dd=dd[-14,]  # causes downturn    
 #dd=dd[-c(1,12),]  # kill speculative bias at 90 and kill high at 540
 #dd=dd[-1,]  # remove bogus first data point since 90 is built into model anyway, or it should be estimated freely
   dd
   
-g <- mkg(topology,free=TRUE)
+g <- mkg(topology,free=free)
+g
+
 bigNms=c("localhost")
 rackLen=c(12,12)
-for (rack in 0:0) for (node in 0:rackLen[rack+1])  bigNms=c(bigNms,paste("compute",rack,node,sep="-"))
+for (rack in 0:1) for (node in 0:rackLen[rack+1])  bigNms=c(bigNms,paste("compute",rack,node,sep="-"))
 big=rep(4,length(bigNms))
 names(big)<-bigNms
-big
-cpusPerHost=c("localhost" = 4,"compute-0-0"=4,"compute-0-1"=4,"compute-0-2"=4,
-    "compute-0-3"=4,"compute-0-4"=4,"compute-0-5"=4,"compute-0-6"=4) # for tk2
+cpusPerHost=big
 if ((host=="tk1")|(host=="stdn")) cpusPerHost=cpusPerHost[1]
 if (host=="rnrClust") cpusPerHost=cpusPerHost[1:5]
 #if (host=="rnrClust") cpusPerHost=cpusPerHost[1]
 #if (host=="dck") cpusPerHost=big
 if (host=="dNTP") cpusPerHost=c("localhost" = 3)
 if (host=="ATP") cpusPerHost=c("localhost" = 1)
-if (host=="tk2") cpusPerHost=cpusPerHost[1]
+if (host=="tk2") cpusPerHost=cpusPerHost[1:9]
 if (host=="dck") cpusPerHost=cpusPerHost[1]
 print(cpusPerHost)
 tops=ems(dd,g,cpusPerHost=cpusPerHost,
-    doGrids=FALSE,doSpurs=TRUE,p=-1,m1=-90,forceM1=F,forceP=F, maxTotalPs=3,
+    doGrids=FALSE,doSpurs=TRUE,p=-1,m1=-90,forceM1=F,forceP=F, maxTotalPs=2,
 #    doGrids=FALSE,doSpurs=TRUE,p=0.9,m1=90,forceM1=T,forceP=T, maxTotalPs=3,
 #    doGrids=TRUE,doSpurs=FALSE,p=0.9,m1=89,forceM1=T,forceP=T, maxTotalPs=4,
     ptype="SOCK",topN=100,KIC=100,transform="none") 
